@@ -43,7 +43,9 @@ def make_exp_dirs(opt):
     else:
         mkdir_and_rename(path_opt.pop('results_root'))
     for key, path in path_opt.items():
-        if ('strict_load' not in key) and ('pretrain_network' not in key) and ('resume' not in key):
+        if ('strict_load' in key) or ('pretrain_network' in key) or ('resume' in key) or ('param_key' in key):
+            continue
+        else:
             os.makedirs(path, exist_ok=True)
 
 
@@ -114,6 +116,13 @@ def check_resume(opt, resume_iter):
                 opt['path'][name] = osp.join(opt['path']['models'], f'net_{basename}_{resume_iter}.pth')
                 print(f"Set {name} to {opt['path'][name]}")
 
+        # change param_key to params in resume
+        param_keys = [key for key in opt['path'].keys() if key.startswith('param_key')]
+        for param_key in param_keys:
+            if opt['path'][param_key] == 'params_ema':
+                opt['path'][param_key] = 'params'
+                print(f'Set {param_key} to params')
+
 
 def sizeof_fmt(size, suffix='B'):
     """Get human readable file size.
